import type { Component } from "vue";
import { defineComponent, h } from 'vue'
import TextConfig from './TextConfig.vue'
import ListConfig from './ListConfig.vue'
import ObjectConfig from './ObjectConfig.vue'
import MarkConfig from "./MarkConfig.vue";
import BooleanConfig from "./BooleanConfig.vue"
import BackgroundConfig from "./BackgroundConfig.vue";
import ImageConfig from "./ImageConfig.vue";
import ColorConfig from './ColorConfig.vue'

const configs: Record<string, Component> = {
  text: TextConfig,
  list: ListConfig,
  object: ObjectConfig,
  mark: MarkConfig,
  boolean: BooleanConfig,
  background: BackgroundConfig,
  image: ImageConfig,
  color: ColorConfig,
}

function render(type: string, props: Record<string, any>) {
  const component = configs[type]
  if (component) {
    return h(configs[type], props)
  }
  return h('div', `unknown type: ${type}`)
}

export const RenderConfig = defineComponent({
  name: 'DddRenderConfig',

  props: {
    type: String,
    props: Object
  },

  setup(props) {
    return () => render(props.type!, props.props!)
  }
})
