const handlers: Record<string, Listener[]> = Object.create(null)

interface Listener {
  fn: (...args: any[]) => void,
  once: boolean
}

export function on(
  type: string,
  fn: (...args: any[]) => void,
  once: boolean = false,
): void {
  const listeners = handlers[type] ?? []
  listeners.push({fn, once})
  handlers[type] = listeners
}

export function emit(type: string, ...args: any[]): void {
  const listeners = handlers[type]
  if (!listeners?.length) return
  for (let i = listeners.length - 1; i >= 0; i--) {
    const ln = listeners[i]
    if (ln.once) {
      handlers[type].splice(i, 1)
    }
    ln.fn(...args)
  }
}
