import type { CSSProperties } from 'vue'
import type { Gradient } from '../types'

function image(img: string | undefined, g: Gradient | undefined): string | undefined {
  if (img == null && g == null) {
    return undefined
  }
  if (img != null) {
    return `url(${img})`
  }
  if (g == null) {
    return undefined
  }
  if (typeof g === 'object') {
    const prefix = g.repeatable ? 'repeating-' : ''
    if (g.stops?.length === g.colors.length) {
      const colors = g.colors.map((c, i) => `${c} ${g.stops![i]}`).join(', ')
      return `${prefix}linear-gradient(${g?.angle ?? '0deg'}, ${colors})`
    }
    return `${prefix}linear-gradient(${g?.angle ?? '0deg'}, ${g.colors.join(', ')})`
  }
}

export function background(color: string | undefined, img: string | undefined, g: Gradient | undefined): CSSProperties {
  return {
    backgroundColor: color,
    backgroundImage: image(img, g),
  }
}
