export function clone<T>(v: T): T {
  switch (typeof v) {
    case "string":
    case "boolean":
    case "number":
    case "undefined":
      return v
    case "symbol":
    case "function":
    case "bigint":
      throw new Error("invalid type")
    case "object":
      if (v == null) {
        return v
      }
      if (Array.isArray(v)) {
        return v.map(clone) as T
      }
      const obj = Object.create(null)
      for (const [key, value] of Object.entries(v)) {
        obj[key] = clone(value)
      }
      return obj
  }
}
