import type { CSSProperties } from 'vue'
import type { DynamicValue, EdgeInsets } from '../types'
import { isSymmetric } from './is'
import { unit } from './unit'

export function insets(name: string, i: DynamicValue<EdgeInsets> | undefined ): CSSProperties | undefined {
  if (i == null) {
    return undefined
  }
  if (typeof i === 'number') {
    return {[name]: `${i}px`}
  }
  if (typeof i === 'string') {
    if(i.split('@@')[1]){
      if(Number.isInteger(i.split('@@')[1])){
        return {[name]: `${i.split('@@')[1]}px`}
      }
      return {[name]: i.split('@@')[1]}
    }


    return {[name]: i}
  }
  if (isSymmetric(i)) {
    return {
      [`${name}Inline`]: i.horizontal != null ? unit(i.horizontal) : undefined,
      [`${name}Block`]: i.vertical != null ? unit(i.vertical) : undefined,
    }
  }
  return {
    [`${name}Top`]: unit(i.top),
    [`${name}Bottom`]: unit(i.bottom),
    [`${name}Left`]: unit(i.left),
    [`${name}Right`]: unit(i.right),
  }
}
