import { createUniqueId } from '../engineer/utils'
import type { Module } from '../engineer'

const module: Module = {
  title: '产品组',
  vid: createUniqueId(),
  mid: createUniqueId(),
  maxReferenceCount: -1,
  referenceCount: 0,
  image: undefined,
  configs: [
    {
      type: 'object',
      field: 'titleAndDesc',
      label: '产品标题及说明',
      configs: [
        {
          type: 'text',
          label: '产品标题',
          field: 'mainTitle'
        },
        {
          type: 'text',
          label: '说明',
          field: 'content',
        },
        {
          type: 'text',
          label: '提示',
          field: 'more',
        },
      ]
    },
    {
      help: '帮助',
      addable: true,
      type: 'list',
      field: 'groups',
      label: '产品组列表',
      configs: [
        {
          type: 'image',
          label: '产品图片',
          field: 'image',
          // 表示内联数据
          inlines: [{
            type: 'text',
            field: 'link',
            label: '链接',
            help: '请输入链接', // 自动生成："请输入${label}"
          },
            {
              type: 'text',
              label: '自定义标题',
              field: 'title',
            },

          ]
        },
      ]
    },
  ],
  init: {
    titleAndDesc: {
      mainTitle: '标题',
      content: '子标题',
      more: '查看更多',
    },
    groups: [
      {
        title: '产品',
      }
    ],
    theme: {
      color: 'pink',
      moreColor: "#5d35b0",
      innerColor: 'white',
      innerRadius: 12,
      productBg: 'pink',
    }
  },
  theme: {
    // height: 200,
    padding: 10,
    color: '@@theme.color',
  },
  children: {
    vid: createUniqueId(),
    theme: {
      width: '100%',
      height: '100%',
      color: '@@theme.innerColor',
      clip: 'hidden',
      radius: '@@theme.innerRadius',
      textAlign: 'center',
    },
    children: [
      {
        theme: {
          flexible: true,
          gap: 12,
          crossAlign: 'center',
        },
        children: [
          {
            theme: {
              padding: {
                horizontal: 5
              },
            },
            children: [
              {
                theme: {
                  flexible: true,
                  gap: 5,
                  crossAlign: 'center',
                },
                children: [
                  {
                    theme: {
                      fontSize: 16,
                    },
                    children: {
                      type: 'text',
                      key: 'titleAndDesc.mainTitle'
                    },
                  },
                  {
                    theme: {
                      fontSize: 16,
                    },
                    children: {
                      type: 'text',
                      key: 'titleAndDesc.content'
                    },
                  }
                ]
              },
            ]
          },
          {
            theme: {
              grow: 1,
            }
          },
          {
            vid: createUniqueId(),
            theme: {
              width: 'auto',
              margin: {
                horizontal: 5,
              },
              fontSize: 12,
              padding: {
                vertical: 1,
                horizontal: 5,
              },
              color: '@@theme.moreColor',
              textColor: '#fff',
              radius: 16,
            },
            children: {
              type: 'text',
              key: 'titleAndDesc.more'
            },
          },

        ],
      },
      {
        vid: createUniqueId(),
        theme: {
          width: "94%",
          height: "70%",
          color: '@@theme.productBg',
          radius: 12.0,
          flexible: true,
          gap: 12,
          margin: {
            top: '1%',
            left: '3%',
            right: '3%',
            bottom: '2%',
          },
          padding: 2,
          clip: 'autoX',
          textAlign: 'left',
        },
        children: {
          type: 'each',
          key: "groups",
          handle: {
            theme: {
              width: 100,
              height: '100%',
              radius: 10,
              color: 'white',
            },
            children: [
              {
                theme: {
                  width: 100,
                  height: 100,
                  border: {
                    color: "@@theme.color",
                    width: 1,
                  },
                },
                children: {
                  type: 'image',
                  key: ".image"
                },
              },
              {
                theme: {
                  textColor: "#333333",
                  fontSize: 15,
                  textAlign: 'center',
                  clip: 'hidden',
                  whiteSpace: 'nowrap'
                },
                children: {
                  type: "text",
                  key: ".title"
                },
              }
            ]
          },
        }
      },
    ]
  }
}

export default module
