import type { Module } from '../engineer'
import { createUniqueId } from '../engineer/utils'

const module:Module = {
  vid: createUniqueId(),
  mid: createUniqueId(),
  title: '轮播图',
  maxReferenceCount: -1,
  referenceCount: 0,
  image: undefined,
  configs: [
    {
      type: 'list',
      field: 'items',
      label: '轮播图设置',
      help: '最多可添加10张图片，建议宽度750px；鼠标拖拽左侧圆点可调整图片顺序',
      addable: true,
      configs: [{
        type: 'image',
        field: 'image',
        label: '图片',
        required: true,
        // 表示内联数据
        inlines: [{
          type: 'text',
          field: 'title',
          label: '标题',
          help: '选填，不超过 4 个字',
        }, {
          type: 'text',
          field: 'link',
          label: '链接',
          help: '请输入链接', // 自动生成："请输入${label}"
        }],
      }],
    },
    {
      type: 'object',
      field: 'indicator',
      label: '指示器',
      configs: [{
        type: 'mark',
        field: 'style',
        label: '指示器样式',
        values: [
          { label: '圆形', value: '#circle' },
          { label: '直线', value: '#line' },
          { label: '数字', value: '#number' },
        ],
      }, {
        type: 'mark',
        field: 'position',
        label: '指示器位置',
        values: [
          { label: '居左', value: 'start' },
          { label: '居中', value: 'center' },
          { label: '居右', value: 'end' },
        ],
      },
        {
          type: 'color',
          field: 'color',
          label: '指示器颜色',
        }],
    },
    {
      type: 'object',
      field: 'background',
      label: '背景',
      configs: [{
        type: 'boolean',
        field: 'enabled',
        label: '是否显示背景色',
      }, {
        type: 'background',
        field: 'value',
        // 背景的不同实现方式，可以在里面添加 image 选项来支持图片
        // 这里只能支持颜色和渐变，
        features: ['color', 'gradient'],
        label: '背景',
      }],
    }
  ],
  init: {
    items: [
      {
        image: '',
        title: '123',
        link: '123',
      }
    ],
    indicator: {
      style: '#circle',
      color: 'green',
      position: 'start',
    },
    background: {
      enabled: true,
      value: "#ffffff",
    },
    theme: {
      color: 'white',
      radius: 24
    }
  },
  templates: {
    '#circle': {
      theme: {
        gap: 1,
      },
      children: {
        type: 'each',
        key: 'items',
        handle: {
          theme: {
            width: 5,
            height: 5,
            radius: 2.5,
            color: '@@indicator.color',
          },
        }
      }
    },
    '#line': {
      theme: {
        gap: 1,
      },
      children: {
        type: 'each',
        key: 'items',
        handle: {
          theme: {
            width: 5,
            height: 2,
            color: '@@indicator.color',
          },
        }
      }
    },
    "#number": {
      theme: {
        color: 'rgba(0,0,0,0.4)',
        textColor: '#fff',
        radius:10,
        padding:{
          left:10,
          right:10
        },
        flexible:true,
        mainAlign:'center',
        crossAlign: 'center'
      },
      children: '1/0'
    }
  },
  theme: {
    position: 'relative',
    height: 200,
    padding: {
      horizontal: 12.0,
      vertical: 12,
    },
    color: 'cyan',
  },
  children: [
    {
      vid: createUniqueId(),
      theme: {
        width: '100%',
        height: '100%',
        color: '@@theme.color',
        radius: "@@theme.radius",
        textAlign: 'center',
      },
      children: '设置轮播图',
    },
    {
      theme: {
        position: 'absolute',
        flexible: true,
        mainAlign: '@@indicator.position',
        bottom: 20,
        left: 30,
        right: 30,
        height: 20,
      },
      children: {
        type: 'template',
        key: 'indicator.style'
      }
    }],
}

export default module
